@@ -287,6 +287,8 @@ static GSupplicantState string2state(const char *state)
 
 	if (g_str_equal(state, "unknown") == TRUE)
 		return G_SUPPLICANT_STATE_UNKNOWN;
+	else if (g_str_equal(state, "interface_disabled") == TRUE)
+		return G_SUPPLICANT_STATE_DISABLED;
 	else if (g_str_equal(state, "disconnected") == TRUE)
 		return G_SUPPLICANT_STATE_DISCONNECTED;
 	else if (g_str_equal(state, "inactive") == TRUE)
@@ -1681,7 +1683,6 @@ static void interface_property(const char *key, DBusMessageIter *iter,
 		debug_strvalmap("Mode capability", mode_capa_map,
 						interface->mode_capa);
 
-		interface->ready = TRUE;
 		callback_interface_added(interface);
 		return;
 	}
@@ -1698,6 +1699,10 @@ static void interface_property(const char *key, DBusMessageIter *iter,
 				interface->state = string2state(str);
 				callback_interface_state(interface);
 			}
+		if (interface->state == G_SUPPLICANT_STATE_DISABLED)
+			interface->ready = FALSE;
+		else
+			interface->ready = TRUE;
 
 		SUPPLICANT_DBG("state %s (%d)", str, interface->state);
 	} else if (g_strcmp0(key, "Scanning") == 0) {
@@ -2695,12 +2700,20 @@ static void interface_scan_result(const char *error,
 				DBusMessageIter *iter, void *user_data)
 {
 	struct interface_scan_data *data = user_data;
+	int err = 0;
 
 	if (error != NULL) {
 		SUPPLICANT_DBG("error %s", error);
+		err = -EIO;
+	}
 
+	/* A non ready interface cannot send/receive anything */
+	if (data->interface->ready == FALSE)
+		err = -ENOLINK;
+
+	if (err != 0) {
 		if (data->callback != NULL)
-			data->callback(-EIO, data->interface, data->user_data);
+			data->callback(err, data->interface, data->user_data);
 	} else {
 		data->interface->scan_callback = data->callback;
 		data->interface->scan_data = data->user_data;
@@ -2857,6 +2870,7 @@ int g_supplicant_interface_scan(GSupplicantInterface *interface,
 	case G_SUPPLICANT_STATE_GROUP_HANDSHAKE:
 		return -EBUSY;
 	case G_SUPPLICANT_STATE_UNKNOWN:
+	case G_SUPPLICANT_STATE_DISABLED:
 	case G_SUPPLICANT_STATE_DISCONNECTED:
 	case G_SUPPLICANT_STATE_INACTIVE:
 	case G_SUPPLICANT_STATE_SCANNING:
