@@ -87,6 +87,7 @@ enum connman_service_proxy_method {
 };
 
 struct connman_service;
+struct connman_network;
 
 struct connman_service *connman_service_create(void);
 
@@ -115,6 +116,14 @@ char **connman_service_get_proxy_servers(struct connman_service *service);
 char **connman_service_get_proxy_excludes(struct connman_service *service);
 const char *connman_service_get_proxy_url(struct connman_service *service);
 const char *connman_service_get_proxy_autoconfig(struct connman_service *service);
+connman_bool_t connman_service_get_favorite(struct connman_service *service);
+
+struct connman_service *connman_service_lookup_from_network(struct connman_network *network);
+
+void connman_service_create_ip4config(struct connman_service *service,
+								int index);
+void connman_service_create_ip6config(struct connman_service *service,
+								int index);
 
 #ifdef __cplusplus
 }
