@@ -636,7 +636,7 @@ static void remove_device_networks(struct connman_device *device)
 		if (connman_network_get_device(network) != device)
 			continue;
 
-		key_list = g_slist_append(key_list, key);
+		key_list = g_slist_prepend(key_list, key);
 	}
 
 	for (list = key_list; list != NULL; list = list->next) {
@@ -705,8 +705,6 @@ static void adapter_properties_reply(DBusPendingCall *call, void *user_data)
 	if (device != NULL)
 		goto update;
 
-	g_hash_table_insert(bluetooth_devices, g_strdup(path), device);
-
 	ether_aton_r(address, &addr);
 
 	snprintf(ident, 13, "%02x%02x%02x%02x%02x%02x",
@@ -721,6 +719,8 @@ static void adapter_properties_reply(DBusPendingCall *call, void *user_data)
 	if (device == NULL)
 		goto done;
 
+	g_hash_table_insert(bluetooth_devices, g_strdup(path), device);
+
 	connman_device_set_ident(device, ident);
 
 	connman_device_set_string(device, "Path", path);
