@@ -425,7 +425,7 @@ struct connman_device *connman_device_create(const char *node,
 	device->networks = g_hash_table_new_full(g_str_hash, g_str_equal,
 						g_free, free_network);
 
-	device_list = g_slist_append(device_list, device);
+	device_list = g_slist_prepend(device_list, device);
 
 	return device;
 }
@@ -589,14 +589,17 @@ int connman_device_set_powered(struct connman_device *device,
 	connman_device_set_disconnected(device, FALSE);
 	device->scanning = FALSE;
 
-	if (device->driver && device->driver->scan_fast)
-		device->driver->scan_fast(device);
-	else if (device->driver && device->driver->scan)
-		device->driver->scan(device);
+	if (device->driver && device->driver->scan)
+		device->driver->scan(device, NULL, 0, NULL, NULL, NULL);
 
 	return 0;
 }
 
+connman_bool_t connman_device_get_powered(struct connman_device *device)
+{
+	return device->powered;
+}
+
 static int device_scan(struct connman_device *device)
 {
 	if (!device->driver || !device->driver->scan)
@@ -605,7 +608,7 @@ static int device_scan(struct connman_device *device)
 	if (device->powered == FALSE)
 		return -ENOLINK;
 
-	return device->driver->scan(device);
+	return device->driver->scan(device, NULL, 0, NULL, NULL, NULL);
 }
 
 int __connman_device_disconnect(struct connman_device *device)
@@ -657,7 +660,8 @@ static void mark_network_unavailable(gpointer key, gpointer value,
 {
 	struct connman_network *network = value;
 
-	if (connman_network_get_connected(network) == TRUE)
+	if (connman_network_get_connected(network) == TRUE ||
+			connman_network_get_connecting(network) == TRUE)
 		return;
 
 	connman_network_set_available(network, FALSE);
@@ -1118,13 +1122,13 @@ int __connman_device_request_hidden_scan(struct connman_device *device,
 	DBG("device %p", device);
 
 	if (device == NULL || device->driver == NULL ||
-			device->driver->scan_hidden == NULL)
+			device->driver->scan == NULL)
 		return -EINVAL;
 
 	if (device->scanning == TRUE)
 		return -EALREADY;
 
-	return device->driver->scan_hidden(device, ssid, ssid_len,
+	return device->driver->scan(device, ssid, ssid_len,
 					identity, passphrase, user_data);
 }
 
